
Here's some data from a named hash, passed by reference.

?$Highlight
******************************
?end
Order Number: 	$OrderNum
Customer Name:	$CustName
?$Highlight
******************************
?end

!$Message
