# Before `make install' is performed this script should be runnable with
# `make test'. After `make install' it should work as `perl test.pl'

######################### We start with some black magic to print on failure.

# Change 1..1 below to 1..last_test_to_print .
# (It may become useful if the test is moved to ./t subdirectory.)

BEGIN { $| = 1; print "1..1\n"; }
END {print "not ok 1\n" unless $loaded;}
use HTML::SimpleTemplate;
$loaded = 1;
print "ok 1\n";

######################### End of black magic.

# Insert your test code below (better if it prints "ok 13"
# (correspondingly "not ok 13") depending on the success of chunk 13
# of the test code):

my $template=new HTML::SimpleTemplate("testtpl");

if ($template)
{
	print "ok 2\n";
} else {
	print "not ok 2\n";
}


$template->Display("test.tpl",{Color=>"green",Number=>1446});


$PageVar{"OrderNum"}=32234;
$PageVar{"Highlight"}=1;
$PageVar{"CustName"}="Mr Turnip";
$PageVar{"Message"}="declined.tpl";

$template->Display("test2.tpl",\%PageVar);

$template->Display("test3.tpl");

